<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2012 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2012-04-23 12:12:12Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Thu, 29 Sep 2011 19:14:35 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_CRArticle extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $articleID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $deleted = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $content = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $title = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $subTitle = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 1
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isVisible = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRUser
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRUser")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name createdBy
     */
    public $createdBy = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRUser
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRUser")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name modifiedBy
     */
    public $modifiedBy = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRUser
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRUser")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name owner
     */
    public $owner = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_CRAttachment")
     * @mandatory 0
     * @destination-entity CRAttachment
     * @to-many 1
     * @name attachments
     */
    public $attachments = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_CREditionArticle")
     * @mandatory 0
     * @destination-entity CREditionArticle
     * @to-many 1
     * @name editionArticles
     */
    public $editionArticles = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRDataNode
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRDataNode")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toLanguageNode
     * @qualifier ((typeID = 31) or (typeID = 0))
     * @default
     * @nodeType Taal
     */
    public $toLanguageNode = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("articleID");
        $entityConfiguration->setName("CRArticle");
    }

    /**
     * Set articleID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setArticleID($value)
    {
        $this->articleID = $value;
        return $this;
    }

    /**
     * Get articleID.
     *
     * @return integer
     */
    public function getArticleID()
    {
        return $this->articleID;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set deleted.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setDeleted($value)
    {
        $this->deleted = $value;
        return $this;
    }

    /**
     * Get deleted.
     *
     * @return integer
     */
    public function getDeleted()
    {
        return $this->deleted;
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set content.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setContent($value)
    {
        $this->content = $value;
        return $this;
    }

    /**
     * Get content.
     *
     * @return string
     */
    public function getContent()
    {
        return $this->content;
    }

    /**
     * Set title.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setTitle($value)
    {
        $this->title = $value;
        return $this;
    }

    /**
     * Get title.
     *
     * @return string
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     * Set subTitle.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setSubTitle($value)
    {
        $this->subTitle = $value;
        return $this;
    }

    /**
     * Get subTitle.
     *
     * @return string
     */
    public function getSubTitle()
    {
        return $this->subTitle;
    }

    /**
     * Set isVisible.
     *
     * Provides a fluent interface.
     *
     * @param integer $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setIsVisible($value)
    {
        $this->isVisible = $value;
        return $this;
    }

    /**
     * Get isVisible.
     *
     * @return integer
     */
    public function getIsVisible()
    {
        return $this->isVisible;
    }

    /**
     * Set createdBy.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRUser $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setCreatedBy($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRUser($value); 
        }                 
        $this->createdBy = $value;
        return $this;
    }

    /**
     * Get createdBy.
     *
     * @return Carerix_Api_Rest_Entity_CRUser
     */
    public function getCreatedBy()
    {
        return $this->createdBy;
    }

    /**
     * Set modifiedBy.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRUser $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setModifiedBy($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRUser($value); 
        }                 
        $this->modifiedBy = $value;
        return $this;
    }

    /**
     * Get modifiedBy.
     *
     * @return Carerix_Api_Rest_Entity_CRUser
     */
    public function getModifiedBy()
    {
        return $this->modifiedBy;
    }

    /**
     * Set owner.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRUser $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setOwner($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRUser($value); 
        }                 
        $this->owner = $value;
        return $this;
    }

    /**
     * Get owner.
     *
     * @return Carerix_Api_Rest_Entity_CRUser
     */
    public function getOwner()
    {
        return $this->owner;
    }

    /**
     * Set attachments.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setAttachments($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values, 'Carerix_Api_Rest_Entity_CRAttachment'); 
        } 
        $this->attachments = $values;
        return $this;
    }

    /**
     * Get attachments.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_CRAttachment
     */
    public function getAttachments($index = null)
    {
        if($index !== null) {
            return $this->attachments[$index];
        }
        return $this->attachments;
    }

    /**
     * Set editionArticles.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setEditionArticles($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values, 'Carerix_Api_Rest_Entity_CREditionArticle'); 
        } 
        $this->editionArticles = $values;
        return $this;
    }

    /**
     * Get editionArticles.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_CREditionArticle
     */
    public function getEditionArticles($index = null)
    {
        if($index !== null) {
            return $this->editionArticles[$index];
        }
        return $this->editionArticles;
    }

    /**
     * Set toLanguageNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRDataNode $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRArticle
     */
    public function setToLanguageNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRDataNode($value); 
        }                 
        $this->toLanguageNode = $value;
        return $this;
    }

    /**
     * Get toLanguageNode.
     *
     * @return Carerix_Api_Rest_Entity_CRDataNode
     */
    public function getToLanguageNode()
    {
        return $this->toLanguageNode;
    }


}