<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2012 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2012-04-23 12:12:12Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Thu, 29 Sep 2011 19:15:11 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_CRContactStatus extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRDataNode
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRDataNode")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toStatusNode
     * @qualifier ((typeID = 17) or (typeID = 0))
     * @default 1
     * @nodeType Contact-status
     */
    public $toStatusNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRUser
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRUser")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name toUser
     */
    public $toUser = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRDataNode
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRDataNode")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toProductNode
     * @qualifier ((typeID = 25) or (typeID = 0))
     * @default
     * @nodeType Product
     */
    public $toProductNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRUser
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRUser")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name owner
     */
    public $owner = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRUser
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRUser")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name createdBy
     */
    public $createdBy = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRUser
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRUser")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name modifiedBy
     */
    public $modifiedBy = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_CRAttributeChange")
     * @mandatory 0
     * @destination-entity CRAttributeChange
     * @to-many 1
     * @name attributeChanges
     * @qualifier (attributeEntityName = 'CRUserStatus')
     */
    public $attributeChanges = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("contactStatusID");
        $entityConfiguration->setName("CRContactStatus");
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set toStatusNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRDataNode $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setToStatusNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRDataNode($value); 
        }                 
        $this->toStatusNode = $value;
        return $this;
    }

    /**
     * Get toStatusNode.
     *
     * @return Carerix_Api_Rest_Entity_CRDataNode
     */
    public function getToStatusNode()
    {
        return $this->toStatusNode;
    }

    /**
     * Set toUser.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRUser $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setToUser($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRUser($value); 
        }                 
        $this->toUser = $value;
        return $this;
    }

    /**
     * Get toUser.
     *
     * @return Carerix_Api_Rest_Entity_CRUser
     */
    public function getToUser()
    {
        return $this->toUser;
    }

    /**
     * Set toProductNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRDataNode $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setToProductNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRDataNode($value); 
        }                 
        $this->toProductNode = $value;
        return $this;
    }

    /**
     * Get toProductNode.
     *
     * @return Carerix_Api_Rest_Entity_CRDataNode
     */
    public function getToProductNode()
    {
        return $this->toProductNode;
    }

    /**
     * Set owner.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRUser $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setOwner($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRUser($value); 
        }                 
        $this->owner = $value;
        return $this;
    }

    /**
     * Get owner.
     *
     * @return Carerix_Api_Rest_Entity_CRUser
     */
    public function getOwner()
    {
        return $this->owner;
    }

    /**
     * Set createdBy.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRUser $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setCreatedBy($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRUser($value); 
        }                 
        $this->createdBy = $value;
        return $this;
    }

    /**
     * Get createdBy.
     *
     * @return Carerix_Api_Rest_Entity_CRUser
     */
    public function getCreatedBy()
    {
        return $this->createdBy;
    }

    /**
     * Set modifiedBy.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRUser $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setModifiedBy($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRUser($value); 
        }                 
        $this->modifiedBy = $value;
        return $this;
    }

    /**
     * Get modifiedBy.
     *
     * @return Carerix_Api_Rest_Entity_CRUser
     */
    public function getModifiedBy()
    {
        return $this->modifiedBy;
    }

    /**
     * Set attributeChanges.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_CRContactStatus
     */
    public function setAttributeChanges($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values, 'Carerix_Api_Rest_Entity_CRAttributeChange'); 
        } 
        $this->attributeChanges = $values;
        return $this;
    }

    /**
     * Get attributeChanges.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_CRAttributeChange
     */
    public function getAttributeChanges($index = null)
    {
        if($index !== null) {
            return $this->attributeChanges[$index];
        }
        return $this->attributeChanges;
    }


}