<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2012 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2012-04-23 12:12:12Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Thu, 29 Sep 2011 19:14:47 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_CREmployeeSkill extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $employeeSkillID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CREmployee
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CREmployee")
     * @mandatory 0
     * @destination-entity CREmployee
     * @to-many 0
     * @name toEmployee
     */
    public $toEmployee = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRDataNode
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRDataNode")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toSkillLevel1
     * @qualifier ((typeID = 33) or (typeID = 0))
     * @default
     * @nodeType Vaardigheid0
     */
    public $toSkillLevel1 = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRDataNode
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRDataNode")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toSkillLevel2
     * @qualifier ((typeID = 34) or (typeID = 0))
     * @default
     * @nodeType Vaardigheid1
     */
    public $toSkillLevel2 = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRDataNode
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRDataNode")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toSkillLevel3
     * @qualifier ((typeID = 35) or (typeID = 0))
     * @default
     * @nodeType Vaardigheid2
     */
    public $toSkillLevel3 = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("employeeSkillID");
        $entityConfiguration->setName("CREmployeeSkill");
    }

    /**
     * Set employeeSkillID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_CREmployeeSkill
     */
    public function setEmployeeSkillID($value)
    {
        $this->employeeSkillID = $value;
        return $this;
    }

    /**
     * Get employeeSkillID.
     *
     * @return integer
     */
    public function getEmployeeSkillID()
    {
        return $this->employeeSkillID;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CREmployeeSkill
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CREmployeeSkill
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CREmployeeSkill
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set toEmployee.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CREmployee $value
     * @return Carerix_Api_Rest_Entity_Abstract_CREmployeeSkill
     */
    public function setToEmployee($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CREmployee($value); 
        }                 
        $this->toEmployee = $value;
        return $this;
    }

    /**
     * Get toEmployee.
     *
     * @return Carerix_Api_Rest_Entity_CREmployee
     */
    public function getToEmployee()
    {
        return $this->toEmployee;
    }

    /**
     * Set toSkillLevel1.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRDataNode $value
     * @return Carerix_Api_Rest_Entity_Abstract_CREmployeeSkill
     */
    public function setToSkillLevel1($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRDataNode($value); 
        }                 
        $this->toSkillLevel1 = $value;
        return $this;
    }

    /**
     * Get toSkillLevel1.
     *
     * @return Carerix_Api_Rest_Entity_CRDataNode
     */
    public function getToSkillLevel1()
    {
        return $this->toSkillLevel1;
    }

    /**
     * Set toSkillLevel2.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRDataNode $value
     * @return Carerix_Api_Rest_Entity_Abstract_CREmployeeSkill
     */
    public function setToSkillLevel2($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRDataNode($value); 
        }                 
        $this->toSkillLevel2 = $value;
        return $this;
    }

    /**
     * Get toSkillLevel2.
     *
     * @return Carerix_Api_Rest_Entity_CRDataNode
     */
    public function getToSkillLevel2()
    {
        return $this->toSkillLevel2;
    }

    /**
     * Set toSkillLevel3.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRDataNode $value
     * @return Carerix_Api_Rest_Entity_Abstract_CREmployeeSkill
     */
    public function setToSkillLevel3($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRDataNode($value); 
        }                 
        $this->toSkillLevel3 = $value;
        return $this;
    }

    /**
     * Get toSkillLevel3.
     *
     * @return Carerix_Api_Rest_Entity_CRDataNode
     */
    public function getToSkillLevel3()
    {
        return $this->toSkillLevel3;
    }


}