<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2012 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2012-04-23 12:12:12Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Thu, 29 Sep 2011 19:15:20 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_CRNewsletterSubscriber extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isActive = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     */
    public $importID = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CREmployee
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CREmployee")
     * @mandatory 0
     * @destination-entity CREmployee
     * @to-many 0
     * @name toEmployee
     */
    public $toEmployee = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRUser
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRUser")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name toUser
     */
    public $toUser = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRNewsletter
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRNewsletter")
     * @mandatory 0
     * @destination-entity CRNewsletter
     * @to-many 0
     * @name toToDo
     */
    public $toToDo = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("newsletterSubscriberID");
        $entityConfiguration->setName("CRNewsletterSubscriber");
    }

    /**
     * Set isActive.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRNewsletterSubscriber
     */
    public function setIsActive($value)
    {
        $this->isActive = $value;
        return $this;
    }

    /**
     * Get isActive.
     *
     * @return integer
     */
    public function getIsActive()
    {
        return $this->isActive;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRNewsletterSubscriber
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRNewsletterSubscriber
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRNewsletterSubscriber
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set toEmployee.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CREmployee $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRNewsletterSubscriber
     */
    public function setToEmployee($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CREmployee($value); 
        }                 
        $this->toEmployee = $value;
        return $this;
    }

    /**
     * Get toEmployee.
     *
     * @return Carerix_Api_Rest_Entity_CREmployee
     */
    public function getToEmployee()
    {
        return $this->toEmployee;
    }

    /**
     * Set toUser.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRUser $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRNewsletterSubscriber
     */
    public function setToUser($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRUser($value); 
        }                 
        $this->toUser = $value;
        return $this;
    }

    /**
     * Get toUser.
     *
     * @return Carerix_Api_Rest_Entity_CRUser
     */
    public function getToUser()
    {
        return $this->toUser;
    }

    /**
     * Set toToDo.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRNewsletter $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRNewsletterSubscriber
     */
    public function setToToDo($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRNewsletter($value); 
        }                 
        $this->toToDo = $value;
        return $this;
    }

    /**
     * Get toToDo.
     *
     * @return Carerix_Api_Rest_Entity_CRNewsletter
     */
    public function getToToDo()
    {
        return $this->toToDo;
    }


}