<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2012 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2012-04-23 12:12:12Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Thu, 29 Sep 2011 19:14:54 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_CRPosting extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $postingID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $lastAttemptDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     */
    public $errorNumber = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $notes = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 1
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $tryCount = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRPublication
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRPublication")
     * @mandatory 0
     * @destination-entity CRPublication
     * @to-many 0
     * @name toPublication
     */
    public $toPublication = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRDataNode
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRDataNode")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toStatusNode
     * @qualifier ((typeID = 86) or (typeID = 0))
     * @default
     * @nodeType Posting-status
     */
    public $toStatusNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_CRMedium
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_CRMedium")
     * @mandatory 0
     * @destination-entity CRMedium
     * @to-many 0
     * @name toMedium
     */
    public $toMedium = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("postingID");
        $entityConfiguration->setName("CRPosting");
    }

    /**
     * Set postingID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setPostingID($value)
    {
        $this->postingID = $value;
        return $this;
    }

    /**
     * Get postingID.
     *
     * @return integer
     */
    public function getPostingID()
    {
        return $this->postingID;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set lastAttemptDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setLastAttemptDate($value)
    {
        $this->lastAttemptDate = $value;
        return $this;
    }

    /**
     * Get lastAttemptDate.
     *
     * @return string
     */
    public function getLastAttemptDate()
    {
        return $this->lastAttemptDate;
    }

    /**
     * Set errorNumber.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setErrorNumber($value)
    {
        $this->errorNumber = $value;
        return $this;
    }

    /**
     * Get errorNumber.
     *
     * @return string
     */
    public function getErrorNumber()
    {
        return $this->errorNumber;
    }

    /**
     * Set notes.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setNotes($value)
    {
        $this->notes = $value;
        return $this;
    }

    /**
     * Get notes.
     *
     * @return string
     */
    public function getNotes()
    {
        return $this->notes;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set tryCount.
     *
     * Provides a fluent interface.
     *
     * @param integer $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setTryCount($value)
    {
        $this->tryCount = $value;
        return $this;
    }

    /**
     * Get tryCount.
     *
     * @return integer
     */
    public function getTryCount()
    {
        return $this->tryCount;
    }

    /**
     * Set toPublication.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRPublication $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setToPublication($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRPublication($value); 
        }                 
        $this->toPublication = $value;
        return $this;
    }

    /**
     * Get toPublication.
     *
     * @return Carerix_Api_Rest_Entity_CRPublication
     */
    public function getToPublication()
    {
        return $this->toPublication;
    }

    /**
     * Set toStatusNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRDataNode $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setToStatusNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRDataNode($value); 
        }                 
        $this->toStatusNode = $value;
        return $this;
    }

    /**
     * Get toStatusNode.
     *
     * @return Carerix_Api_Rest_Entity_CRDataNode
     */
    public function getToStatusNode()
    {
        return $this->toStatusNode;
    }

    /**
     * Set toMedium.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_CRMedium $value
     * @return Carerix_Api_Rest_Entity_Abstract_CRPosting
     */
    public function setToMedium($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_CRMedium($value); 
        }                 
        $this->toMedium = $value;
        return $this;
    }

    /**
     * Get toMedium.
     *
     * @return Carerix_Api_Rest_Entity_CRMedium
     */
    public function getToMedium()
    {
        return $this->toMedium;
    }


}